@@ -37,7 +37,7 @@ def bytes2human(n):
     for s in reversed(symbols):
         if n >= prefix[s]:
             value = float(n) / prefix[s]
-            return '%.1f%s' % (value, s)
+            return f'{value:.1f}{s}'
     return "%sB" % n
 
 
