@@ -51,18 +51,24 @@ class PhotomStep(RomanStep):
                                      'spectral data')
                     self.log.warning('Photom step will be skipped')
                     input_model.meta.cal_step.photom = 'SKIPPED'
+                    input_model.meta.photometry.pixelarea_arcsecsq = None
+                    input_model.meta.photometry.pixelarea_steradians = None
+                    input_model.meta.photometry.conversion_megajanskys = None
+                    input_model.meta.photometry.conversion_microjanskys = None
+                    input_model.meta.photometry.conversion_megajanskys_uncertainty = None
+                    input_model.meta.photometry.conversion_microjanskys_uncertainty = None
                     try:
                         photom_model.close()
                     except AttributeError:
                         pass
-                    return input_model
+                    output_model = input_model
 
             else:
                 # Skip Photom step if no photom file
                 self.log.warning('No PHOTOM reference file found')
                 self.log.warning('Photom step will be skipped')
                 input_model.meta.cal_step.photom = 'SKIPPED'
-                return input_model
+                output_model = input_model
 
         # Close the input and reference files
         input_model.close()
