@@ -21,23 +21,23 @@ def test_basic_saturation_flagging(setup_wfi_datamodels):
     nrows = 20
     ncols = 20
     satvalue = 60000
-    data, satmap = setup_wfi_datamodels(ngroups, nrows, ncols)
+    ramp, satmap = setup_wfi_datamodels(ngroups, nrows, ncols)
 
     # Add ramp values up to the saturation limit
-    data.data[0, 5, 5] = 0
-    data.data[1, 5, 5] = 20000
-    data.data[2, 5, 5] = 40000
-    data.data[3, 5, 5] = 60000   # Signal reaches saturation limit
-    data.data[4, 5, 5] = 62000
+    ramp.data[0, 5, 5] = 0 * ramp.data.unit
+    ramp.data[1, 5, 5] = 20000 * ramp.data.unit
+    ramp.data[2, 5, 5] = 40000 * ramp.data.unit
+    ramp.data[3, 5, 5] = 60000 * ramp.data.unit  # Signal reaches saturation limit
+    ramp.data[4, 5, 5] = 62000 * ramp.data.unit
 
     # Set saturation value in the saturation model
-    satmap.data[5, 5] = satvalue
+    satmap.data[5, 5] = satvalue * satmap.data.unit
 
     # Run the pipeline
-    output = flag_saturation(data, satmap)
+    output = flag_saturation(ramp, satmap)
 
     # Make sure that groups with signal > saturation limit get flagged
-    satindex = np.argmax(output.data[:, 5, 5] == satvalue)
+    satindex = np.argmax(output.data.value[:, 5, 5] == satvalue)
     assert np.all(output.groupdq[satindex:, 5, 5] == dqflags.group['SATURATED'])
 
 def test_ad_floor_flagging(setup_wfi_datamodels):
@@ -50,23 +50,23 @@ def test_ad_floor_flagging(setup_wfi_datamodels):
     ncols = 20
     satvalue = 60000
 
-    data, satmap = setup_wfi_datamodels(ngroups, nrows, ncols)
+    ramp, satmap = setup_wfi_datamodels(ngroups, nrows, ncols)
 
     # Add ramp values up to the saturation limit
-    data.data[0, 5, 5] = 0  # Signal at bottom rail - low saturation
-    data.data[1, 5, 5] = 0  # Signal at bottom rail - low saturation
-    data.data[2, 5, 5] = 20
-    data.data[3, 5, 5] = 40
-    data.data[4, 5, 5] = 60
+    ramp.data[0, 5, 5] = 0 * ramp.data.unit   # Signal at bottom rail - low saturation
+    ramp.data[1, 5, 5] = 0 * ramp.data.unit   # Signal at bottom rail - low saturation
+    ramp.data[2, 5, 5] = 20 * ramp.data.unit
+    ramp.data[3, 5, 5] = 40 * ramp.data.unit
+    ramp.data[4, 5, 5] = 60 * ramp.data.unit
 
     # frames that should be flagged as saturation (low)
     satindxs = [0, 1]
 
     # Set saturation value in the saturation model
-    satmap.data[5, 5] = satvalue
+    satmap.data[5, 5] = satvalue * satmap.data.unit
 
     # Run the pipeline
-    output = flag_saturation(data, satmap)
+    output = flag_saturation(ramp, satmap)
 
     # Check if the right frames are flagged as saturated
     assert np.all(output.groupdq[satindxs, 5, 5]
@@ -83,14 +83,14 @@ def test_ad_floor_and_saturation_flagging(setup_wfi_datamodels):
     ncols = 20
     satvalue = 60000
 
-    data, satmap = setup_wfi_datamodels(ngroups, nrows, ncols)
+    ramp, satmap = setup_wfi_datamodels(ngroups, nrows, ncols)
 
     # Add ramp values up to the saturation limit
-    data.data[0, 5, 5] = 0  # Signal at bottom rail - low saturation
-    data.data[1, 5, 5] = 0  # Signal at bottom rail - low saturation
-    data.data[2, 5, 5] = 20
-    data.data[3, 5, 5] = 40
-    data.data[4, 5, 5] = 61000  # Signal above the saturation threshold
+    ramp.data[0, 5, 5] = 0 * ramp.data.unit  # Signal at bottom rail - low saturation
+    ramp.data[1, 5, 5] = 0 * ramp.data.unit  # Signal at bottom rail - low saturation
+    ramp.data[2, 5, 5] = 20 * ramp.data.unit
+    ramp.data[3, 5, 5] = 40 * ramp.data.unit
+    ramp.data[4, 5, 5] = 61000 * ramp.data.unit  # Signal above the saturation threshold
 
     # frames that should be flagged as ad_floor
     floorindxs = [0, 1]
@@ -98,10 +98,10 @@ def test_ad_floor_and_saturation_flagging(setup_wfi_datamodels):
     satindxs = [4]
 
     # Set saturation value in the saturation model
-    satmap.data[5, 5] = satvalue
+    satmap.data[5, 5] = satvalue * satmap.data.unit
 
     # Run the pipeline
-    output = flag_saturation(data, satmap)
+    output = flag_saturation(ramp, satmap)
 
     # Check if the right frames are flagged as ad_floor
     assert np.all(output.groupdq[floorindxs, 5, 5]
@@ -121,23 +121,23 @@ def test_signal_fluctuation_flagging(setup_wfi_datamodels):
     ncols = 20
     satvalue = 60000
 
-    data, satmap = setup_wfi_datamodels(ngroups, nrows, ncols)
+    ramp, satmap = setup_wfi_datamodels(ngroups, nrows, ncols)
 
     # Add ramp values up to the saturation limit
-    data.data[0, 5, 5] = 10
-    data.data[1, 5, 5] = 20000
-    data.data[2, 5, 5] = 40000
-    data.data[3, 5, 5] = 60000   # Signal reaches saturation limit
-    data.data[4, 5, 5] = 40000   # Signal drops below saturation limit
+    ramp.data[0, 5, 5] = 10 * ramp.data.unit
+    ramp.data[1, 5, 5] = 20000 * ramp.data.unit
+    ramp.data[2, 5, 5] = 40000 * ramp.data.unit
+    ramp.data[3, 5, 5] = 60000 * ramp.data.unit   # Signal reaches saturation limit
+    ramp.data[4, 5, 5] = 40000 * ramp.data.unit   # Signal drops below saturation limit
 
     # Set saturation value in the saturation model
-    satmap.data[5, 5] = satvalue
+    satmap.data[5, 5] = satvalue * satmap.data.unit
 
     # Run the pipeline
-    output = flag_saturation(data, satmap)
+    output = flag_saturation(ramp, satmap)
 
     # Make sure that all groups after first saturated group are flagged
-    satindex = np.argmax(output.data[:, 5, 5] == satvalue)
+    satindex = np.argmax(output.data.value[:, 5, 5] == satvalue)
     assert np.all(output.groupdq[satindex:, 5, 5] == dqflags.group['SATURATED'])
 
 
@@ -150,20 +150,20 @@ def test_all_groups_saturated(setup_wfi_datamodels):
     ncols = 20
     satvalue = 60000
 
-    data, satmap = setup_wfi_datamodels(ngroups, nrows, ncols)
+    ramp, satmap = setup_wfi_datamodels(ngroups, nrows, ncols)
 
     # Add ramp values at or above saturation limit
-    data.data[0, 5, 5] = 60000
-    data.data[1, 5, 5] = 62000
-    data.data[2, 5, 5] = 62000
-    data.data[3, 5, 5] = 60000
-    data.data[4, 5, 5] = 62000
+    ramp.data[0, 5, 5] = 60000 * ramp.data.unit
+    ramp.data[1, 5, 5] = 62000 * ramp.data.unit
+    ramp.data[2, 5, 5] = 62000 * ramp.data.unit
+    ramp.data[3, 5, 5] = 60000 * ramp.data.unit
+    ramp.data[4, 5, 5] = 62000 * ramp.data.unit
 
     # Set saturation value in the saturation model
-    satmap.data[5, 5] = satvalue
+    satmap.data[5, 5] = satvalue * satmap.data.unit
 
     # Run the pipeline
-    output = flag_saturation(data, satmap)
+    output = flag_saturation(ramp, satmap)
 
     # Make sure all groups are flagged
     assert np.all(output.groupdq[:, 5, 5] == dqflags.group['SATURATED'])
@@ -178,14 +178,14 @@ def test_dq_propagation(setup_wfi_datamodels):
     dqval1 = 5
     dqval2 = 10
 
-    data, satmap = setup_wfi_datamodels(ngroups, nrows, ncols)
+    ramp, satmap = setup_wfi_datamodels(ngroups, nrows, ncols)
 
     # Add DQ values to the data and reference file
-    data.pixeldq[5, 5] = dqval1
+    ramp.pixeldq[5, 5] = dqval1
     satmap.dq[5, 5] = dqval2
 
     # Run the pipeline
-    output = flag_saturation(data, satmap)
+    output = flag_saturation(ramp, satmap)
 
     # Make sure DQ values from data and reference file are added in the output
     assert output.pixeldq[5, 5] == dqval1 + dqval2
@@ -201,24 +201,24 @@ def test_no_sat_check(setup_wfi_datamodels):
     ncols = 20
     satvalue = 60000
 
-    data, satmap = setup_wfi_datamodels(ngroups, nrows, ncols)
+    ramp, satmap = setup_wfi_datamodels(ngroups, nrows, ncols)
 
     # Add ramp values up to the saturation limit
-    data.data[0, 5, 5] = 10
-    data.data[1, 5, 5] = 20000
-    data.data[2, 5, 5] = 40000
-    data.data[3, 5, 5] = 60000
-    data.data[4, 5, 5] = 62000   # Signal reaches saturation limit
+    ramp.data[0, 5, 5] = 10 * ramp.data.unit
+    ramp.data[1, 5, 5] = 20000 * ramp.data.unit
+    ramp.data[2, 5, 5] = 40000 * ramp.data.unit
+    ramp.data[3, 5, 5] = 60000 * ramp.data.unit
+    ramp.data[4, 5, 5] = 62000 * ramp.data.unit   # Signal reaches saturation limit
 
     # Set saturation value in the saturation model & DQ value for NO_SAT_CHECK
-    satmap.data[5, 5] = satvalue
+    satmap.data[5, 5] = satvalue * satmap.data.unit
     satmap.dq[5, 5] = dqflags.pixel['NO_SAT_CHECK']
 
     # Also set an existing DQ flag in input science data
-    data.pixeldq[5, 5] = dqflags.pixel['DO_NOT_USE']
+    ramp.pixeldq[5, 5] = dqflags.pixel['DO_NOT_USE']
 
     # Run the pipeline
-    output = flag_saturation(data, satmap)
+    output = flag_saturation(ramp, satmap)
 
     # Make sure output GROUPDQ does not get flagged as saturated
     # Make sure PIXELDQ is set to NO_SAT_CHECK and original flag
@@ -239,20 +239,20 @@ def test_nans_in_mask(setup_wfi_datamodels):
     nrows = 20
     ncols = 20
 
-    data, satmap = setup_wfi_datamodels(ngroups, nrows, ncols)
+    ramp, satmap = setup_wfi_datamodels(ngroups, nrows, ncols)
 
     # Add ramp values up to the saturation limit
-    data.data[0, 5, 5] = 10
-    data.data[1, 5, 5] = 20000
-    data.data[2, 5, 5] = 40000
-    data.data[3, 5, 5] = 60000
-    data.data[4, 5, 5] = 62000
+    ramp.data[0, 5, 5] = 10 * ramp.data.unit
+    ramp.data[1, 5, 5] = 20000 * ramp.data.unit
+    ramp.data[2, 5, 5] = 40000 * ramp.data.unit
+    ramp.data[3, 5, 5] = 60000 * ramp.data.unit
+    ramp.data[4, 5, 5] = 62000 * ramp.data.unit
 
     # Set saturation value for pixel to NaN
-    satmap.data[5, 5] = np.nan
+    satmap.data[5, 5] = np.nan * satmap.data.unit
 
     # Run the pipeline
-    output = flag_saturation(data, satmap)
+    output = flag_saturation(ramp, satmap)
 
     # Check that output GROUPDQ is not flagged as saturated
     assert np.all(output.groupdq[:, 5, 5] != dqflags.group['SATURATED'])
@@ -266,11 +266,11 @@ def setup_wfi_datamodels():
     def _models(ngroups, nrows, ncols):
 
         # Create ramp data
-        data_model = testutil.mk_ramp(shape=(ngroups, nrows, ncols))
+        ramp_model = testutil.mk_ramp(shape=(ngroups, nrows, ncols))
 
         # Create saturation reference data
         saturation_model = testutil.mk_saturation(shape=(nrows, ncols))
 
-        return data_model, saturation_model
+        return ramp_model, saturation_model
 
     return _models
